@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0019';
+our $VERSION = '0.0020';
 
 use Moo;
 use strictures 2;
@@ -150,12 +150,30 @@ sub search_settings {
 }
 
 
+sub recall_models {
+  my ($self) = @_;
+  my @models;
+  my $results = $self->_sqlite->query(
+    "select name from sqlite_schema where type='table' order by name"
+  );
+  while (my $next = $results->array) {
+    next if $next->[0] =~ /^sqlite/;
+    push @models, $next->[0];
+  }
+  return \@models;
+}
+
+
 sub recall_names {
   my ($self) = @_;
+  my @names;
   my $results = $self->_sqlite->query(
     'select distinct name from ' . $self->model
-  )->array;
-  return $results;
+  );
+  while (my $next = $results->array) {
+    push @names, $next->[0];
+  }
+  return \@names;
 }
 
 
@@ -204,7 +222,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0019
+version 0.0020
 
 =head1 SYNOPSIS
 
@@ -225,6 +243,9 @@ version 0.0019
   # update the etc key only
   $synth->make_setting(id => $id1, etc => '!!!');
 
+  my $models = $synth->recall_models;
+  # [ 'moog_matriarch' ]
+
   my $names = $synth->recall_names;
   # [ 'Foo!' ]
 
@@ -323,6 +344,12 @@ Return all the settings for the synth model.
 
 Return all the settings given a search query.
 
+=head2 recall_models
+
+  my $models = $synth->recall_models;
+
+Return all the models.
+
 =head2 recall_names
 
   my $names = $synth->recall_names;
